__author__ = 'v.denisov'

class InterestedParties:

    def __init__(self):
        pass

    @classmethod
    def person(self):
        interested_parties_person = {
            "composer":{
                "type": 3,
                "name_first": "Композитор",
                "name_last": "Композитор",
                "name_middle": "",
                "ip_name_number": "",
                "gender": 2,
                "date_start": "",
                "date_end": "",
                "date_not_protected": "",
                "nationality": "",
                "note": "",
                "object_info": ""
            },
            "corpse":{
                "type": 3,
                "name_first": "Мертвец",
                "name_last": "Мертвец",
                "name_middle": "",
                "ip_name_number": "",
                "gender": 1,
                "date_start": "06.11.1900",
                "date_end": "04.11.1930",
                "date_not_protected": "04.11.2000",
                "nationality": "",
                "note": "Произведения не охраняются",
                "object_info": ""
            }

        }
        return interested_parties_person


__author__ = 'v.denisov'

import allure
from rais.config_host import ConfigHost as config

class ParameterInitialization:

    def __init__(self):
        pass

    @classmethod
    @allure.step('set url_host')
    def set_url_host(self, url_host):
        config.url_host = url_host

    @classmethod
    @allure.step('get url_host')
    def get_url_host(self):
        return config.url_host

    @classmethod
    @allure.step('set cookies')
    def set_cookies(self, cookies):
        config.cookies = cookies

    @classmethod
    @allure.step('get cookies')
    def get_cookies(self):
        return config.cookies

    @classmethod
    @allure.step('set headers')
    def set_headers(self, headers):
        config.headers = headers

    @classmethod
    @allure.step('get headers')
    def get_headers(self):
        return config.headers

    @classmethod
    @allure.step('set prefix')
    def set_prefix(self, prefix):
        config.prefix = prefix

    @classmethod
    @allure.step('get prefix')
    def get_prefix(self):
        return config.prefix
